@@ -45,22 +45,50 @@ NULL
 
 #' dat_1.
 #'
-#' FLUOstar .dat files used for creation of the update and unusable for data immediate data analysis.
+#' FLUOstar .dat files used for creation of the update and unusable for immediate data analysis.
 #'
 #'
 "dat_1"
 
 #' dat_2.
 #'
-#' FLUOstar .dat files used for creation of the update and unusable for data immediate data analysis.
+#' FLUOstar .dat files used for creation of the update and unusable for immediate data analysis.
 #'
 #'
 "dat_2"
 
 #' dat_3.
 #'
-#' FLUOstar .dat files used for creation of the update and unusable for data immediate data analysis. 
+#' FLUOstar .dat files used for creation of the update and unusable for immediate data analysis.
 #' This file is unique because it validates a major bug fix to ensure that users get the right output.
 #'
 "dat_3"
 
+#' dat_4.
+#'
+#' FLUOstar .dat files used for creation of the update and unusable for immediate data analysis.
+#' This file is unique because it validates a major bug fix to ensure that users get the right output.
+#'
+"dat_4"
+
+#' dat_5.
+#'
+#' FLUOstar .dat files used for creation of the update and unusable for immediate data analysis.
+#' This file is unique because it validates a major bug fix to ensure that users get the right output.
+#'
+"dat_5"
+
+#' dat_6.
+#'
+#' FLUOstar .dat files used for creation of the update and unusable for immediate data analysis.
+#' This file is unique because it validates a major bug fix to ensure that users get the right output.
+#'
+"dat_6"
+
+#' dat_7.
+#'
+#' FLUOstar .dat files used for creation of the update and unusable for immediate data analysis.
+#' This file is unique because it validates a major bug fix to ensure that users get the right output.
+#'
+"dat_7"
+
